# tiled2zx0

Simple command to convert Tiled map (.tmx) into compressed (with Einar Saukas ZX0) bin file.

## Install

pip install tiled2zx0

## Run

```bash
usage: tiled2zx0 [-h] [-o OUTPUT_FILE] /path/map.tmx

Process some arguments.

options:
  -h, --help            show this help message and exit
  -h OUTPUT_FILE, --output OUTPUT
                        Output file
```

## Attribution

This project use [ZX0 compressor by Einar Saukas](https://github.com/einar-saukas/ZX0) binaries.
